@@ -6,6 +6,7 @@ from .brandon import Brandon
 from .format import JsonChecker
 from .human import HumanChecker
 from .regex import RegexList
+from .what import What
 
 
 @registry.register
@@ -41,11 +42,8 @@ class EzCheck(Checker[str]):
 
         # We need to modify the config for each of the objects
 
-        # First the flag regexes, as they are the fastest
-        flags_config = config
-        flags_config.update_param("regexlist", "resource", "cipheydists::list::flags")
-        # We do not cache, as this uses a different, on-time config
-        self.checkers.append(RegexList(flags_config))
+        # First PyWhat, as it's the fastest
+        self.checkers.append(config(What))
 
         # Next, the json checker
         self.checkers.append(config(JsonChecker))
